#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// CLI entry point for Segment MCP Server
function runCLI() {
    return __awaiter(this, void 0, void 0, function* () {
        console.error("Starting Segment MCP Server CLI...");
        try {
            const { loadConfig, validateConfig } = yield Promise.resolve().then(() => __importStar(require("./utils/config.js")));
            const config = loadConfig();
            validateConfig(config);
            const { SegmentMcp } = yield Promise.resolve().then(() => __importStar(require("./server/segment-mcp.js")));
            const server = new SegmentMcp({ config });
            if (config.transport === "stdio") {
                const { createStdioTransport } = yield Promise.resolve().then(() => __importStar(require("./transports/stdio.js")));
                const transport = createStdioTransport();
                yield server.start(transport);
                console.error("Segment MCP Server connected via stdio and ready to handle requests");
            }
            else if (config.transport === "http") {
                const { createHttpTransportManager } = yield Promise.resolve().then(() => __importStar(require("./transports/http.js")));
                const httpManager = createHttpTransportManager(server.getServer(), config);
                yield httpManager.start();
                console.error("Segment MCP Server connected via HTTP and ready to handle requests");
                // Handle graceful shutdown for HTTP
                const shutdown = () => __awaiter(this, void 0, void 0, function* () {
                    console.error("Shutting down HTTP server...");
                    yield httpManager.stop();
                    process.exit(0);
                });
                process.on("SIGINT", shutdown);
                process.on("SIGTERM", shutdown);
            }
            else {
                throw new Error(`Unsupported transport: ${config.transport}`);
            }
        }
        catch (error) {
            console.error("Failed to start Segment MCP Server:", error);
            console.error("Error stack:", error.stack);
            process.exit(1);
        }
    });
}
// Handle graceful shutdown for stdio mode
process.on("SIGINT", () => {
    console.error("\nShutting down Segment MCP Server...");
    process.exit(0);
});
process.on("SIGTERM", () => {
    console.error("\nShutting down Segment MCP Server...");
    process.exit(0);
});
// Add uncaught exception handler
process.on("uncaughtException", (error) => {
    console.error("Uncaught Exception:", error);
    console.error("Error stack:", error.stack);
    process.exit(1);
});
// Add unhandled rejection handler
process.on("unhandledRejection", (reason, promise) => {
    console.error("Unhandled Rejection at:", promise);
    console.error("Reason:", reason);
    process.exit(1);
});
// Run CLI
console.error("Starting CLI mode...");
runCLI().catch((error) => {
    console.error("Fatal error in CLI:", error);
    console.error("Error stack:", error.stack);
    process.exit(1);
});
//# sourceMappingURL=cli.js.map