"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SegmentProfileClient = void 0;
const axios_1 = __importDefault(require("axios"));
class SegmentProfileClient {
    constructor(config) {
        this.spaceId = config.spaceId;
        this.client = axios_1.default.create({
            baseURL: config.profileApiBaseUrl,
            headers: {
                Authorization: `Basic ${btoa(config.profileApiToken + ":")}`,
                "Content-Type": "application/json",
            },
            timeout: 30000,
        });
    }
    /**
     * Get user traits by external ID (e.g., email:user@example.com)
     */
    getProfileTraits(externalId, spaceId) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            try {
                const space = spaceId || this.spaceId;
                const response = yield this.client.get(`/v1/spaces/${space}/collections/users/profiles/${externalId}/traits`);
                return response.data;
            }
            catch (error) {
                if (((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) === 404) {
                    throw new Error(`Profile not found for external ID: ${externalId}`);
                }
                throw new Error(`Failed to get profile traits: ${error.message}`);
            }
        });
    }
    /**
     * Get user events by external ID (e.g., email:user@example.com)
     */
    getProfileEvents(externalId_1) {
        return __awaiter(this, arguments, void 0, function* (externalId, options = {}) {
            var _a;
            try {
                const space = options.spaceId || this.spaceId;
                const queryParams = new URLSearchParams();
                if (options.limit) {
                    queryParams.append("limit", options.limit.toString());
                }
                if (options.cursor) {
                    queryParams.append("cursor", options.cursor);
                }
                if (options.include) {
                    queryParams.append("include", options.include);
                }
                if (options.exclude) {
                    queryParams.append("exclude", options.exclude);
                }
                const url = `/v1/spaces/${space}/collections/users/profiles/${externalId}/events`;
                const fullUrl = queryParams.toString()
                    ? `${url}?${queryParams.toString()}`
                    : url;
                const response = yield this.client.get(fullUrl);
                return response.data;
            }
            catch (error) {
                if (((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) === 404) {
                    throw new Error(`Profile not found for external ID: ${externalId}`);
                }
                throw new Error(`Failed to get profile events: ${error.message}`);
            }
        });
    }
}
exports.SegmentProfileClient = SegmentProfileClient;
//# sourceMappingURL=profile-client.js.map