"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SegmentTrackingClient = void 0;
const axios_1 = __importDefault(require("axios"));
class SegmentTrackingClient {
    constructor(config) {
        this.writeKey = config.trackingWriteKey;
        this.client = axios_1.default.create({
            baseURL: config.trackingApiBaseUrl,
            headers: {
                "Content-Type": "application/json",
            },
            timeout: 10000,
            auth: {
                username: config.trackingWriteKey,
                password: "",
            },
        });
    }
    /**
     * Send a track event to Segment
     */
    track(event) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const payload = Object.assign(Object.assign({}, event), { type: "track", timestamp: event.timestamp || new Date().toISOString(), context: Object.assign({ library: {
                            name: "segment-mcp-server",
                            version: "1.0.0",
                        } }, event.context) });
                yield this.client.post("/track", payload);
            }
            catch (error) {
                throw new Error(`Failed to track event: ${error.message}`);
            }
        });
    }
    /**
     * Send an identify event to Segment
     */
    identify(event) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const payload = Object.assign(Object.assign({}, event), { type: "identify", timestamp: event.timestamp || new Date().toISOString(), context: Object.assign({ library: {
                            name: "segment-mcp-server",
                            version: "1.0.0",
                        } }, event.context) });
                yield this.client.post("/identify", payload);
            }
            catch (error) {
                throw new Error(`Failed to identify user: ${error.message}`);
            }
        });
    }
    /**
     * Track AI conversation started event
     */
    trackAIConversationStarted(userId_1, conversationId_1) {
        return __awaiter(this, arguments, void 0, function* (userId, conversationId, properties = {}, anonymousId) {
            const event = {
                userId,
                anonymousId,
                event: "AI Conversation Started",
                properties: Object.assign({ conversation_id: conversationId }, properties),
            };
            yield this.track(event);
        });
    }
    /**
     * Track AI conversation ended event
     */
    trackAIConversationEnded(userId_1, conversationId_1) {
        return __awaiter(this, arguments, void 0, function* (userId, conversationId, properties = {}, anonymousId) {
            const event = {
                userId,
                anonymousId,
                event: "AI Conversation Ended",
                properties: Object.assign({ conversation_id: conversationId }, properties),
            };
            yield this.track(event);
        });
    }
    /**
     * Track AI message sent event
     */
    trackAIMessageSent(userId_1, conversationId_1, messageContent_1) {
        return __awaiter(this, arguments, void 0, function* (userId, conversationId, messageContent, properties = {}, anonymousId) {
            const event = {
                userId,
                anonymousId,
                event: "AI Message Sent",
                properties: Object.assign({ conversation_id: conversationId, message_content: messageContent }, properties),
            };
            yield this.track(event);
        });
    }
    /**
     * Track AI response received event
     */
    trackAIResponseReceived(userId_1, conversationId_1, responseContent_1) {
        return __awaiter(this, arguments, void 0, function* (userId, conversationId, responseContent, properties = {}, anonymousId) {
            const event = {
                userId,
                anonymousId,
                event: "AI Response Received",
                properties: Object.assign({ conversation_id: conversationId, response_content: responseContent }, properties),
            };
            yield this.track(event);
        });
    }
    /**
     * Track AI feedback event
     */
    trackAIFeedback(userId, conversationId, messageId, feedbackType, feedbackValue, feedbackText, anonymousId) {
        return __awaiter(this, void 0, void 0, function* () {
            const event = {
                userId,
                anonymousId,
                event: "AI Feedback Given",
                properties: {
                    conversation_id: conversationId,
                    message_id: messageId,
                    feedback_type: feedbackType,
                    feedback_value: feedbackValue,
                    feedback_text: feedbackText,
                },
            };
            yield this.track(event);
        });
    }
    /**
     * Batch track multiple events
     */
    batchTrack(events) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const payload = {
                    batch: events.map((event) => (Object.assign(Object.assign({}, event), { type: "track", timestamp: event.timestamp || new Date().toISOString(), context: Object.assign({ library: {
                                name: "segment-mcp-server",
                                version: "1.0.0",
                            } }, event.context) }))),
                };
                yield this.client.post("/batch", payload);
            }
            catch (error) {
                throw new Error(`Failed to batch track events: ${error.message}`);
            }
        });
    }
}
exports.SegmentTrackingClient = SegmentTrackingClient;
//# sourceMappingURL=tracking-client.js.map