import { StreamableHTTPServerTransport } from "@modelcontextprotocol/sdk/server/streamableHttp.js";
import { randomUUID } from "node:crypto";
import { createHttpTransportManager as createHttpManager, } from "../utils/http-transport-simple.mjs";
/**
 * Create a simple StreamableHTTPServerTransport for single-session usage
 */
export function createHttpTransport(options = {}) {
    const sessionId = randomUUID();
    return new StreamableHTTPServerTransport({
        enableJsonResponse: options.enableJsonResponse ?? true,
        sessionIdGenerator: () => sessionId,
        onsessioninitialized: (actualId) => {
            console.log(`HTTP Session initialized: ${actualId}`);
        },
    });
}
/**
 * Create an HTTP transport manager for multi-session usage
 * This returns a manager that can handle multiple client sessions
 */
export function createHttpTransportManager(server, config) {
    return createHttpManager(server, config);
}
/**
 * Start an HTTP server that can handle multiple MCP sessions
 */
export async function startHttpServer(server, options) {
    const manager = createHttpTransportManager(server, options.config);
    await manager.start();
    return manager;
}
//# sourceMappingURL=http.js.map