import { z } from "zod";
export declare const TrackAIConversationSchema: z.ZodObject<{
    user_id: z.ZodString;
    conversation_id: z.ZodString;
    event_type: z.ZodEnum<["conversation_started", "conversation_ended", "message_sent", "response_received"]>;
    properties: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        model_name: z.ZodOptional<z.ZodString>;
        input_tokens: z.ZodOptional<z.ZodNumber>;
        output_tokens: z.ZodOptional<z.ZodNumber>;
        response_time_ms: z.ZodOptional<z.ZodNumber>;
        conversation_context: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        success: z.ZodOptional<z.ZodBoolean>;
        error_details: z.ZodOptional<z.ZodString>;
        message_content: z.ZodOptional<z.ZodString>;
        response_content: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        model_name?: string | undefined;
        input_tokens?: number | undefined;
        output_tokens?: number | undefined;
        response_time_ms?: number | undefined;
        conversation_context?: Record<string, any> | undefined;
        success?: boolean | undefined;
        error_details?: string | undefined;
        message_content?: string | undefined;
        response_content?: string | undefined;
    }, {
        model_name?: string | undefined;
        input_tokens?: number | undefined;
        output_tokens?: number | undefined;
        response_time_ms?: number | undefined;
        conversation_context?: Record<string, any> | undefined;
        success?: boolean | undefined;
        error_details?: string | undefined;
        message_content?: string | undefined;
        response_content?: string | undefined;
    }>>>;
    anonymous_id: z.ZodOptional<z.ZodString>;
    timestamp: z.ZodOptional<z.ZodString>;
}, "strict", z.ZodTypeAny, {
    conversation_id: string;
    properties: {
        model_name?: string | undefined;
        input_tokens?: number | undefined;
        output_tokens?: number | undefined;
        response_time_ms?: number | undefined;
        conversation_context?: Record<string, any> | undefined;
        success?: boolean | undefined;
        error_details?: string | undefined;
        message_content?: string | undefined;
        response_content?: string | undefined;
    };
    user_id: string;
    event_type: "conversation_started" | "conversation_ended" | "message_sent" | "response_received";
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
}, {
    conversation_id: string;
    user_id: string;
    event_type: "conversation_started" | "conversation_ended" | "message_sent" | "response_received";
    properties?: {
        model_name?: string | undefined;
        input_tokens?: number | undefined;
        output_tokens?: number | undefined;
        response_time_ms?: number | undefined;
        conversation_context?: Record<string, any> | undefined;
        success?: boolean | undefined;
        error_details?: string | undefined;
        message_content?: string | undefined;
        response_content?: string | undefined;
    } | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
}>;
export declare const TrackAIQuerySchema: z.ZodObject<{
    user_id: z.ZodString;
    conversation_id: z.ZodString;
    query: z.ZodString;
    response: z.ZodOptional<z.ZodString>;
    model_used: z.ZodString;
    response_time_ms: z.ZodOptional<z.ZodNumber>;
    success: z.ZodBoolean;
    error_details: z.ZodOptional<z.ZodString>;
    anonymous_id: z.ZodOptional<z.ZodString>;
    timestamp: z.ZodOptional<z.ZodString>;
    additional_properties: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
}, "strict", z.ZodTypeAny, {
    conversation_id: string;
    success: boolean;
    user_id: string;
    query: string;
    model_used: string;
    response_time_ms?: number | undefined;
    error_details?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    response?: string | undefined;
    additional_properties?: Record<string, any> | undefined;
}, {
    conversation_id: string;
    success: boolean;
    user_id: string;
    query: string;
    model_used: string;
    response_time_ms?: number | undefined;
    error_details?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    response?: string | undefined;
    additional_properties?: Record<string, any> | undefined;
}>;
export declare const TrackAIFeedbackSchema: z.ZodObject<{
    user_id: z.ZodString;
    conversation_id: z.ZodString;
    message_id: z.ZodString;
    feedback_type: z.ZodEnum<["thumbs_up", "thumbs_down", "rating"]>;
    feedback_value: z.ZodOptional<z.ZodNumber>;
    feedback_text: z.ZodOptional<z.ZodString>;
    anonymous_id: z.ZodOptional<z.ZodString>;
    timestamp: z.ZodOptional<z.ZodString>;
    additional_properties: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
}, "strict", z.ZodTypeAny, {
    conversation_id: string;
    message_id: string;
    feedback_type: "thumbs_up" | "thumbs_down" | "rating";
    user_id: string;
    feedback_value?: number | undefined;
    feedback_text?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    additional_properties?: Record<string, any> | undefined;
}, {
    conversation_id: string;
    message_id: string;
    feedback_type: "thumbs_up" | "thumbs_down" | "rating";
    user_id: string;
    feedback_value?: number | undefined;
    feedback_text?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    additional_properties?: Record<string, any> | undefined;
}>;
export declare const TrackEventSchema: z.ZodEffects<z.ZodObject<{
    user_id: z.ZodOptional<z.ZodString>;
    anonymous_id: z.ZodOptional<z.ZodString>;
    event: z.ZodString;
    properties: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    timestamp: z.ZodOptional<z.ZodString>;
    context: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    integrations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
}, "strip", z.ZodTypeAny, {
    event: string;
    properties?: Record<string, any> | undefined;
    user_id?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    context?: Record<string, any> | undefined;
    integrations?: Record<string, any> | undefined;
}, {
    event: string;
    properties?: Record<string, any> | undefined;
    user_id?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    context?: Record<string, any> | undefined;
    integrations?: Record<string, any> | undefined;
}>, {
    event: string;
    properties?: Record<string, any> | undefined;
    user_id?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    context?: Record<string, any> | undefined;
    integrations?: Record<string, any> | undefined;
}, {
    event: string;
    properties?: Record<string, any> | undefined;
    user_id?: string | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    context?: Record<string, any> | undefined;
    integrations?: Record<string, any> | undefined;
}>;
export declare const IdentifyEventSchema: z.ZodObject<{
    user_id: z.ZodString;
    traits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    anonymous_id: z.ZodOptional<z.ZodString>;
    timestamp: z.ZodOptional<z.ZodString>;
    context: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    integrations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
}, "strict", z.ZodTypeAny, {
    user_id: string;
    traits?: Record<string, any> | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    context?: Record<string, any> | undefined;
    integrations?: Record<string, any> | undefined;
}, {
    user_id: string;
    traits?: Record<string, any> | undefined;
    anonymous_id?: string | undefined;
    timestamp?: string | undefined;
    context?: Record<string, any> | undefined;
    integrations?: Record<string, any> | undefined;
}>;
export type TrackAIConversationInput = z.infer<typeof TrackAIConversationSchema>;
export type TrackAIQueryInput = z.infer<typeof TrackAIQuerySchema>;
export type TrackAIFeedbackInput = z.infer<typeof TrackAIFeedbackSchema>;
export type TrackEventInput = z.infer<typeof TrackEventSchema>;
export type IdentifyEventInput = z.infer<typeof IdentifyEventSchema>;
//# sourceMappingURL=tracking-schemas.d.ts.map